// SPDX-FileCopyrightText: 2020 - 2022 Uniontech Software Technology Co.,Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef QT5DWAYLANDPLUGIN_H
#define QT5DWAYLANDPLUGIN_H

#include "qt5dwayland-plugin_global.h"

class QT5DWAYLANDPLUGINSHARED_EXPORT Qt5dwaylandplugin
{

public:
    Qt5dwaylandplugin();
};

#endif // QT5DWAYLANDPLUGIN_H
