// SPDX-FileCopyrightText: 2020 - 2022 Uniontech Software Technology Co.,Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "qt5dwaylandplugin.h"

Qt5dwaylandplugin::Qt5dwaylandplugin()
{

}
